import { select,
         scaleLinear,
         extent,
         axisLeft,
         axisBottom
       } from "d3"

export const scatterPlot = (selection, props) => {
	const {
    xValue,
    yValue,
    margin,
    radius,
    xLegend,
    yLegend,
    width,
    height,
    data
  } = props;

  const innerWidth = width - margin.left - margin.right
  const innerHeight = height - margin.top - margin.bottom
  
  
  const xScale = scaleLinear()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();
  
  const yScale = scaleLinear()
  	.domain(extent(data, yValue))
  	.range([0, innerHeight])
  	.nice();
  
  let g = selection.selectAll('.container').data([null]);
  const gEnter = g
  	.enter().append('g')
  		.attr('class', 'container');
  gEnter.merge(g)
  		.attr('transform', `translate(${margin.left}, ${margin.top})`);

  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.tickPadding(15);
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(10);
  
  const yAxisG = g.select('.y-axis');
  const yAxisGEnter = gEnter
  	.append('g')
  		.attr('class', 'y-axis');
  yAxisG
  	.merge(yAxisGEnter)
   	 .call(yAxis)
  	 .selectAll('.domain').remove();
  
  const yAxisLabelText = yAxisGEnter
    .append('text')
      .attr('class', 'yLegend')
      .attr('transform', 'rotate(-90)')
      .attr('fill', 'black')
      .attr('text-anchor','middle')
      .attr('y', -50)
  	.merge(yAxisG.select('.yLegend'))
  		.attr('x', -innerHeight / 2)
		  .text(yLegend);
  
  
  const xAxisG = g.select('.x-axis');
  const xAxisGEnter = gEnter
  	.append('g')
  		.attr('class', 'x-axis');
  xAxisG
  	.merge(xAxisGEnter)
   		.attr('transform', `translate(0, ${innerHeight})`) 
    .call(xAxis)
  	 .selectAll('.domain').remove();
  
  const xAxisLabelText = xAxisGEnter
    .append('text')
      .attr('class', 'xLegend')
      .attr('fill', 'black')
      .attr('text-anchor','middle')
      .attr('y', 50)
  	.merge(xAxisG.select('.xLegend'))
  		.attr('x', innerWidth / 2)
		  .text(xLegend);

  
  const circles = g.merge(gEnter).selectAll('circle').data(data);
  const circlesEnter = circles.enter()
  	.append('circle')
  		.attr('cx', innerWidth / 2)
  		.attr('cy', innerHeight / 2)
  		.attr('r', 0)
  	.merge(circles).transition().delay((d, i) => i*10)
  		.attr('cy', d => yScale(yValue(d)))
  		.attr('cx', d => xScale(xValue(d)))
 			.attr('r', radius)
  	

  const tooltip = select('body').append('div')
  	.attr('class', 'tooltip')
  	.style("position", "absolute")
    .style("visibility", "hidden")
  	.style('transform', 'translate(-50%, 0)');
  const getInfo = d => `${d.name} ${d.origin} | Acc: ${d.acceleration}`
  g.selectAll('circle')
  	.on("mouseover", d => tooltip.style("visibility", "visible").text(getInfo(d)))
  	.on("mousemove", function(){tooltip.style('top', `${event.pageY-50}px`).style('left', `${event.pageX}px`)})
    .on("mouseout", function(){tooltip.style("visibility", "hidden").text('')})
}